=============================================================
:mod:`xoutil.pprint` -- Extension to the data pretty printer.
=============================================================
.. module:: xoutil.pprint

This modules includes all the Python's standard library features in module
``pprint`` and adds the function :func:`ppformat`, which just returns a string
of the pretty-formatted object.

.. versionadded:: 1.4.1

.. autofunction:: ppformat
